@@ -20,7 +20,7 @@ topic_list_str_sub = ''
 def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000))):
     global server_url, server_port, client_id
     server_url = url
-    server_port = port
+    server_port = int(port)
     client_id = clientID
 
 
